#define MOZ_SOURCE_STAMP e6d6eb0ce3c42b4ebca91b1b1b64b716b2acb9fd
#define MOZ_SOURCE_REPO https://hg.mozilla.org/releases/mozilla-beta
#define MOZ_SOURCE_URL https://hg.mozilla.org/releases/mozilla-beta/rev/e6d6eb0ce3c42b4ebca91b1b1b64b716b2acb9fd
